@@ -11,7 +11,6 @@
    #include <botan/x509path.h>
    #include <botan/certstor.h>
    #include <botan/calendar.h>
-   #include <botan/cert_status.h>
    #include <fstream>
 #endif
 
@@ -335,7 +334,9 @@ class OCSP_Tests final : public Test
             {
             if(result.test_eq("Expected size of ocsp_status[0]", ocsp_status[0].size(), 1))
                {
-               result.confirm("Status ok", ocsp_status[0].count(Botan::Certificate_Status_Code::OCSP_RESPONSE_GOOD) > 0);
+               const bool status_good = ocsp_status[0].count(Botan::Certificate_Status_Code::OCSP_RESPONSE_GOOD) > 0;
+               const bool server_not_found = ocsp_status[0].count(Botan::Certificate_Status_Code::OCSP_SERVER_NOT_AVAILABLE) > 0;
+               result.confirm("Expected status", status_good || server_not_found);
                }
             }
 
@@ -368,7 +369,7 @@ class OCSP_Tests final : public Test
          }
    };
 
-BOTAN_REGISTER_TEST("ocsp", OCSP_Tests);
+BOTAN_REGISTER_TEST("x509", "ocsp", OCSP_Tests);
 
 #endif
 
