@@ -14,6 +14,7 @@
    #include <botan/x509self.h>
    #include <botan/x509path.h>
    #include <botan/x509_ca.h>
+   #include <botan/x509_ext.h>
    #include <botan/pk_algs.h>
    #include <botan/ber_dec.h>
    #include <botan/der_enc.h>
@@ -603,7 +604,7 @@ Test::Result test_verify_gost2012_cert()
    {
    Test::Result result("X509 GOST-2012 certificates");
 
-#if defined(BOTAN_HAS_GOST_34_10_2012) && defined(BOTAN_HAS_STREEBOG)
+#if defined(BOTAN_HAS_GOST_34_10_2012) && defined(BOTAN_HAS_STREEBOG) && defined(BOTAN_HAS_EMSA1)
    try
       {
       Botan::X509_Certificate root_cert(Test::data_file("x509/gost/gost_root.pem"));
@@ -1600,6 +1601,11 @@ class X509_Cert_Unit_Tests final : public Test
                continue;
 #endif
 
+#if !defined(BOTAN_HAS_EMSA1)
+            if(algo != "RSA" && algo != "Ed25519")
+               continue;
+#endif
+
             std::unique_ptr<Botan::Private_Key> key = make_a_private_key(algo);
 
             if(key == nullptr)
@@ -1727,7 +1733,7 @@ class X509_Cert_Unit_Tests final : public Test
          }
    };
 
-BOTAN_REGISTER_TEST("x509_unit", X509_Cert_Unit_Tests);
+BOTAN_REGISTER_TEST("x509", "x509_unit", X509_Cert_Unit_Tests);
 
 #endif
 
